==> elgg-1.9.2.zip: elgg-1.9.2/mod/groups/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Grupos",
	'groups:owned' => "Grupos que administro",
	'groups:owned:user' => 'Grupos que administra %s',
	'groups:yours' => "Mis grupos",
	'groups:user' => "Grupos de %s",
	'groups:all' => "Todos los grupos",
	'groups:add' => "Crear un nuevo grupo",
	'groups:edit' => "Editar grupo",
	'groups:delete' => 'Borrar grupo',
	'groups:membershiprequests' => 'Manejar solicitudes de uni&oacute;n a grupos',
	'groups:membershiprequests:pending' => 'Manage join requests (%s)',
	'groups:invitations' => 'Invitaciones de grupo',
	'groups:invitations:pending' => 'Group invitations (%s)',

	'groups:icon' => '&iacute;cono de grupo (dejar en blanco para no hacer cambios)',
	'groups:name' => 'Nombre del Grupo',
	'groups:username' => 'Nombre corto del Grupo (mostrado en la URL, s&oacute;lo caracteres alfanum&eacute;ricos)',
	'groups:description' => 'Descripci&oacute;n completa',
	'groups:briefdescription' => 'Breve descripci&oacute;n',
	'groups:interests' => 'Etiquetas',
	'groups:website' => 'Sitio Web',
	'groups:members' => 'Miembros del grupo',
	'groups:my_status' => 'My status',
	'groups:my_status:group_owner' => 'You own this group',
	'groups:my_status:group_member' => 'You are in this group',
	'groups:subscribed' => 'Group notifications on',
	'groups:unsubscribed' => 'Group notifications off',

	'groups:members:title' => 'Miembros de %s',
	'groups:members:more' => "Ver todos los miembros",
	'groups:membership' => "Ver los permisos de los miembros",
	'groups:content_access_mode' => "Accesabilidad del contenido del grupo",
	'groups:content_access_mode:warning' => "Advertencia: Cambiar esta preferencia no cambiara los permisos de acceso al contenido existente en el grupo.",
	'groups:content_access_mode:unrestricted' => "Sin restringir &mdash; el acceso depende de la configuración individual de cada contenido.",
	'groups:content_access_mode:membersonly' => "Solo miembros - Los que no son miembros nunca podrán accesar al contenido del grupo",
	'groups:access' => "Permisos de acceso",
	'groups:owner' => "Propietario",
	'groups:owner:warning' => "Warning: if you change this value, you will no longer be the owner of this group.",
	'groups:widget:num_display' => 'N&uacute;mero de miembros a mostrar',
	'groups:widget:membership' => 'Miembros del grupo',
	'groups:widgets:description' => 'Muestra los grupos en dond eeres miembro',

	'groups:widget:group_activity:title' => 'Actividad del grupo',
	'groups:widget:group_activity:description' => 'Ver la actividad en uno de tus grupos',
	'groups:widget:group_activity:edit:select' => 'Selecciona un grupo',
	'groups:widget:group_activity:content:noactivity' => 'No hay actividad en este grupo',
	'groups:widget:group_activity:content:noselect' => 'Editar este widget para seleccionar un grupo',

	'groups:noaccess' => 'No hay acceso al grupo',
	'groups:permissions:error' => 'No tienes permisos para esto',
	'groups:ingroup' => 'en el grupo',
	'groups:cantcreate' => 'You can not create a group. Only admins can.',
	'groups:cantedit' => 'No puedes editar este grupo',
	'groups:saved' => 'Grupo guardado',
	'groups:featured' => 'Grupos destacados',
	'groups:makeunfeatured' => 'No destacar',
	'groups:makefeatured' => 'Destacar',
	'groups:featuredon' => '%s es miembro de un grupo destacado.',
	'groups:unfeatured' => '%s has been removed from the featured groups.',
	'groups:featured_error' => 'Grupo inv&aacute;lido.',
	'groups:nofeatured' => 'Sin grupos destacados.',
	'groups:joinrequest' => 'Solicitar unirse',
	'groups:join' => 'Unirse al grupo',
	'groups:leave' => 'Abandonar el grupo',
	'groups:invite' => 'Invitar amigos',
	'groups:invite:title' => 'Invitar amigos a este grupo',
	'groups:inviteto' => "Invitar amigos a '%s'",
	'groups:nofriends' => "No hay amigos que no hayan sido invitados al grupo.",
	'groups:nofriendsatall' => 'No hay amigos para invitar',
	'groups:viagroups' => "via grupos",
	'groups:group' => "Grupo",
	'groups:search:tags' => "etiqueta",
	'groups:search:title' => "Search for groups tagged with '%s'",
	'groups:search:none' => "No matching groups were found",
	'groups:search_in_group' => "Search in this group",
	'groups:acl' => "Group: %s",

	'discussion:topic:notify:summary' => 'Nuevo tema de discusión llamado %s',
	'discussion:topic:notify:subject' => 'Nuevo tema de discusión: %s',
	'discussion:topic:notify:body' =>
'%s ha agregado un nuevo tema al grupo %s:

Título: %s

%s

Ver y responder:
%s
',

	'discussion:reply:notify:summary' => 'Nueva respuesta en tema: %s',
	'discussion:reply:notify:subject' => 'Nueva respuesta en tema: %s',
	'discussion:reply:notify:body' =>
'%s ha respondido al tema %s en el grupo %s:

%s

Ver y comentar:
%s
',

	'groups:activity' => "Actividad del grupo",
	'groups:enableactivity' => 'Habilitar las actividades del grupo',
	'groups:activity:none' => "El grupo no ha tenido actividades a&uacute;n",

	'groups:notfound' => "No se encontr&oacute; el grupo",
	'groups:notfound:details' => "El grupo solicitado no existe o no tienes permiso para verlo",

	'groups:requests:none' => 'No hay solicitudes de membres&iacute;a.',

	'groups:invitations:none' => 'Actualmente no hay invitaciones.',

	'item:object:groupforumtopic' => "Temas de discusi&oacute;n",
	'item:object:discussion_reply' => "Respuestas de la discusión",

	'groupforumtopic:new' => "A&ntilde;adir un tema de discusi&oacute;n",

	'groups:count' => "Grupos creados",
	'groups:open' => "grupo abierto",
	'groups:closed' => "grupo cerrado",
	'groups:member' => "miembros",
	'groups:searchtag' => "Buscar grupos por etiqueta",

	'groups:more' => 'M&aacute;s grupos',
	'groups:none' => 'No hay grupos',

	/**
	 * Access
	 */
	'groups:access:private' => 'Cerrado &mdash; los miembros deben ser invitados',
	'groups:access:public' => 'Abierto &mdash; cualquiera puede unirse',
	'groups:access:group' => 'S&oacute;lo miembros del grupo',
	'groups:closedgroup' => "La membresía de este grupo esta cerrada.",
	'groups:closedgroup:request' => 'Para pedir ser agregado, de click sobre el link "Pedir membresía".',
	'groups:closedgroup:membersonly' => "La membresía de este grupo es cerrada y su contenido solo puede ser accesible para los miembros.",
	'groups:opengroup:membersonly' => "El contenido de este grupo solo es accesible por sus miembros.",
	'groups:opengroup:membersonly:join' => 'Para ser un miembro, de click sobre el link de "Unirse al grupo".',
	'groups:visibility' => '&iquest;Quienes pueden ver este grupo?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Habilitar discusi&oacute;n de los grupos',
	'groups:lastupdated' => '&Uacute;ltimas actualizaciones de %s por %s',
	'groups:lastcomment' => '&Uacute;ltimos de %s por %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Discusi&oacute;n',
	'discussion:add' => 'Agregar tema de discusi&oacute;n',
	'discussion:latest' => '&uacute;ltimas discusiones',
	'discussion:group' => 'Discusiones de grupo',
	'discussion:none' => 'No hay discusiones',
	'discussion:reply:title' => 'Respuesta de %s',

	'discussion:topic:created' => 'El tema de discusi&oacute;n ha sido creado.',
	'discussion:topic:updated' => 'El tema de discusi&oacute;n ha sido actualizado.',
	'discussion:topic:deleted' => 'El tema de discusi&oacute;n ha sido borrado.',

	'discussion:topic:notfound' => 'No se ha encontrado el tema de discusi&oacute;n. solicitado',
	'discussion:error:notsaved' => 'No se puede guardar el tema de discusi&oacute;n',
	'discussion:error:missing' => 'El t&iacute;tulo y el cuerpo del mensaje son obligatorios',
	'discussion:error:permissions' => 'No tienes permiso para hacer eso',
	'discussion:error:notdeleted' => 'No se pudo borrar el tema de discusi&oacute;n',

	'discussion:reply:edit' => 'Editar respuesta',
	'discussion:reply:deleted' => 'La respuesta ha sido borrada.',
	'discussion:reply:error:notfound' => 'La respuesta de la discusión no fue encontrada',
	'discussion:reply:error:notdeleted' => 'No se pudo borrar la respuesta',

	'admin:groups' => 'Grupos',

	'reply:this' => 'Responder a esto',

	'group:replies' => 'Respuestas',
	'groups:forum:created' => 'Creado %s con %d comentarios',
	'groups:forum:created:single' => 'creado %s con %d respuestas',
	'groups:forum' => 'Discusi&oacute;n',
	'groups:addtopic' => 'Agregar un tema',
	'groups:forumlatest' => '&uacute;ltima discusi&oacute;n',
	'groups:latestdiscussion' => '&uacute;ltimas discusiones',
	'groupspost:success' => 'Tu respuesta ha sido publicada',
	'groupspost:failure' => 'Hubo un problema al publicar tu respuesta',
	'groups:alldiscussion' => '&uacute;ltima discusi&oacute;n',
	'groups:edittopic' => 'Editar tema',
	'groups:topicmessage' => 'Mensaje del tema',
	'groups:topicstatus' => 'Estado del tema',
	'groups:reply' => 'Publicar un comentario',
	'groups:topic' => 'Tema',
	'groups:posts' => 'Publicaciones',
	'groups:lastperson' => '&Uacute;ltimo usuario',
	'groups:when' => 'Cuando',
	'grouptopic:notcreated' => 'No hay temas creados.',
	'groups:topicclosed' => 'Cerrado',
	'grouptopic:created' => 'Tu tema ha sido creado.',
	'groups:topicsticky' => 'Sticky',
	'groups:topicisclosed' => 'Esta discusi&oacute;n est&aacute; cerrada.',
	'groups:topiccloseddesc' => 'Este tema est&aacute; cerrado y no acepta nuevas respuestas.',
	'grouptopic:error' => 'El grupo no pudo ser creado. Por favor intenta de nuevo o contacta con el administrador.',
	'groups:forumpost:edited' => "Has editado la entrada exitosamente.",
	'groups:forumpost:error' => "Hubo un problema al editar la entrada.",

	'groups:privategroup' => 'Este es un grupo cerrado. Debes solicitar membresía.',
	'groups:notitle' => 'El grupo debe tener un t&iacute;tulo',
	'groups:cantjoin' => 'No se puedo unir al grupo',
	'groups:cantleave' => 'No se pudo abandonar el grupo',
	'groups:removeuser' => 'Remover del grupo',
	'groups:cantremove' => 'No se puede remover este usuario del grupo',
	'groups:removed' => 'El usuario %s ha sido removido del grupo',
	'groups:addedtogroup' => 'El usuario ha sido agregado con &eacute;xito',
	'groups:joinrequestnotmade' => 'No se pudo enviar la solicitud de membres&iacute;a del grupo',
	'groups:joinrequestmade' => 'Solicitar unirse al grupo',
	'groups:joined' => 'Te has unido al grupo',
	'groups:left' => 'Has abandonado el grupo',
	'groups:notowner' => 'No eres el propietario del grupo.',
	'groups:notmember' => 'No eres miembro de este grupo.',
	'groups:alreadymember' => 'Ya eres miembro de este grupo',
	'groups:userinvited' => 'El usuario ha sido invitado.',
	'groups:usernotinvited' => 'El usuario no pudo ser invitado.',
	'groups:useralreadyinvited' => 'El uuario ya ha sido invitado',
	'groups:invite:subject' => "%s te ha invitado al grupo %s",
	'groups:updated' => "&Uacute;ltima respuesta en %s de %s",
	'groups:started' => "Iniciado por %s",
	'groups:joinrequest:remove:check' => '&iquest;Seguro que deseas cancelar la solicitud de membres&iacute;a?',
	'groups:invite:remove:check' => '&iquest;Seguro que deseas anular esta invitaci&oacute;n?',
	'groups:invite:body' => "Hi %s,

%s te ha invitado para que te unas al grupo '%s'. Haz click en el siguiente enlace para unirte:

%s",

	'groups:welcome:subject' => "Bienvenido al grupo %s",
	'groups:welcome:body' => "Hola %s!

Ahora eres miembro de '%s'. Haz click en el siguiente enlace para empezar a postear:

%s",

	'groups:request:subject' => "%s ha solicitado unirse a %s",
	'groups:request:body' => "Hola %s,

%s ha solicitado unirse al grupo '%s'. Click en el siguiente enlace para ver el perfil:

%s

O click a continuaci&oacute;n para ver las solicitudes de membres&iacute;a del grupo:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s ha creado el grupo %s',
	'river:join:group:default' => '%s se ha unido al grupo %s',
	'river:create:object:groupforumtopic' => '%s abri&oacute; el tema %s',
	'river:reply:object:groupforumtopic' => '%s ha respondido en el tema %s',
	'river:reply:view' => 'Ver la respuesta',

	'groups:nowidgets' => 'No se han definido widgets para el grupo.',


	'groups:widgets:members:title' => 'Miembros del grupo',
	'groups:widgets:members:description' => 'Lista de miembros del grupo.',
	'groups:widgets:members:label:displaynum' => 'Lista de miembros de un grupo.',
	'groups:widgets:members:label:pleaseedit' => 'Por favor configura este widget.',

	'groups:widgets:entities:title' => "Objetos en el grupo",
	'groups:widgets:entities:description' => "Lista de objetos guardados en este grupo",
	'groups:widgets:entities:label:displaynum' => 'Lista de objetos de este grupo.',
	'groups:widgets:entities:label:pleaseedit' => 'Por favor configura este widget.',

	'groups:forumtopic:edited' => 'Tema de discusi&oacute;n guaddado con &eacute;xito.',

	'groups:allowhiddengroups' => '&iquest;Desea habilitar los grupos provados?',
	'groups:whocancreate' => 'Who can create new groups?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Grupo y contenidos borrados',
	'group:notdeleted' => 'El grupo no pudo ser borrado',

	'group:notfound' => 'No se pudo encontrar el Grupo',
	'grouppost:deleted' => 'Publicaci&oacute;n del grupo borrada con &eacute;xito',
	'grouppost:notdeleted' => 'La publicaci&oacute;n del grupo no se pudoborrar',
	'groupstopic:deleted' => 'Tema eliminado',
	'groupstopic:notdeleted' => 'No se pudo borrar el tema',
	'grouptopic:blank' => 'No hay temas',
	'grouptopic:notfound' => 'No se pude encontrar el tema solicitado',
	'grouppost:nopost' => 'Post vacio',
	'groups:deletewarning' => "&iquest;Seguro que deseas borrar este grupo? No se puede deshacer",

	'groups:invitekilled' => 'El invitado ha sido eliminado.',
	'groups:joinrequestkilled' => 'La solicitud ha sido borrada.',
	'groups:error:addedtogroup' => "No ha sido posible añadir a %s al grupo.",
	'groups:add:alreadymember' => "%s ya forma parte del grupo.",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Discusi&oacute;n de los grupos',
	'groups:ecml:groupprofile' => 'Pefiles de los grupos',
);

==> elgg-1.10.1.zip: elgg-1.10.1/mod/groups/languages/es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Grupos",
	'groups:owned' => "Grupos que administro",
	'groups:owned:user' => 'Grupos que administra %s',
	'groups:yours' => "Mis grupos",
	'groups:user' => "Grupos de %s",
	'groups:all' => "Todos los grupos",
	'groups:add' => "Crear un nuevo grupo",
	'groups:edit' => "Editar grupo",
	'groups:delete' => 'Borrar grupo',
	'groups:membershiprequests' => 'Manejar solicitudes de uni&oacute;n a grupos',
	'groups:membershiprequests:pending' => 'Manage join requests (%s)',
	'groups:invitations' => 'Invitaciones de grupo',
	'groups:invitations:pending' => 'Group invitations (%s)',

	'groups:icon' => '&iacute;cono de grupo (dejar en blanco para no hacer cambios)',
	'groups:name' => 'Nombre del Grupo',
	'groups:username' => 'Nombre corto del Grupo (mostrado en la URL, s&oacute;lo caracteres alfanum&eacute;ricos)',
	'groups:description' => 'Descripci&oacute;n completa',
	'groups:briefdescription' => 'Breve descripci&oacute;n',
	'groups:interests' => 'Etiquetas',
	'groups:website' => 'Sitio Web',
	'groups:members' => 'Miembros del grupo',
	'groups:my_status' => 'Mi estado',
	'groups:my_status:group_owner' => 'Eres dueño de este grupo',
	'groups:my_status:group_member' => 'Usted está en este grupo',
	'groups:subscribed' => 'Group notifications on',
	'groups:unsubscribed' => 'Group notifications off',

	'groups:members:title' => 'Miembros de %s',
	'groups:members:more' => "Ver todos los miembros",
	'groups:membership' => "Ver los permisos de los miembros",
	'groups:content_access_mode' => "Accesabilidad del contenido del grupo",
	'groups:content_access_mode:warning' => "Advertencia: Cambiar esta preferencia no cambiara los permisos de acceso al contenido existente en el grupo.",
	'groups:content_access_mode:unrestricted' => "Sin restringir &mdash; el acceso depende de la configuración individual de cada contenido.",
	'groups:content_access_mode:membersonly' => "Solo miembros - Los que no son miembros nunca podrán accesar al contenido del grupo",
	'groups:access' => "Permisos de acceso",
	'groups:owner' => "Propietario",
	'groups:owner:warning' => "Advertencia: si cambia este valor, usted ya no es el dueño de este grupo.",
	'groups:widget:num_display' => 'N&uacute;mero de miembros a mostrar',
	'groups:widget:membership' => 'Miembros del grupo',
	'groups:widgets:description' => 'Muestra los grupos en dond eeres miembro',

	'groups:widget:group_activity:title' => 'Actividad del grupo',
	'groups:widget:group_activity:description' => 'Ver la actividad en uno de tus grupos',
	'groups:widget:group_activity:edit:select' => 'Selecciona un grupo',
	'groups:widget:group_activity:content:noactivity' => 'No hay actividad en este grupo',
	'groups:widget:group_activity:content:noselect' => 'Editar este widget para seleccionar un grupo',

	'groups:noaccess' => 'No hay acceso al grupo',
	'groups:permissions:error' => 'No tienes permisos para esto',
	'groups:ingroup' => 'en el grupo',
	'groups:cantcreate' => 'No se puede crear un grupo. Sólo los administradores pueden.',
	'groups:cantedit' => 'No puedes editar este grupo',
	'groups:saved' => 'Grupo guardado',
	'groups:featured' => 'Grupos destacados',
	'groups:makeunfeatured' => 'No destacar',
	'groups:makefeatured' => 'Destacar',
	'groups:featuredon' => '%s es miembro de un grupo destacado.',
	'groups:unfeatured' => '%s se ha eliminado de los grupos destacados.',
	'groups:featured_error' => 'Grupo inv&aacute;lido.',
	'groups:nofeatured' => 'Sin grupos destacados.',
	'groups:joinrequest' => 'Solicitar unirse',
	'groups:join' => 'Unirse al grupo',
	'groups:leave' => 'Abandonar el grupo',
	'groups:invite' => 'Invitar amigos',
	'groups:invite:title' => 'Invitar amigos a este grupo',
	'groups:inviteto' => "Invitar amigos a '%s'",
	'groups:nofriends' => "No hay amigos que no hayan sido invitados al grupo.",
	'groups:nofriendsatall' => 'No hay amigos para invitar',
	'groups:viagroups' => "via grupos",
	'groups:group' => "Grupo",
	'groups:search:tags' => "etiqueta",
	'groups:search:title' => "Búsqueda de grupos etiquetados con  '%s'",
	'groups:search:none' => "No se encontraron grupos que coincidan",
	'groups:search_in_group' => "Buscar en este grupo",
	'groups:acl' => "Group: '%s'",

	'discussion:topic:notify:summary' => 'Nuevo tema de discusión llamado %s',
	'discussion:topic:notify:subject' => 'Nuevo tema de discusión: %s',
	'discussion:topic:notify:body' =>
'%s ha agregado un nuevo tema al grupo %s:

Título: %s

%s

Ver y responder:
%s
',

	'discussion:reply:notify:summary' => 'Nueva respuesta en tema: %s',
	'discussion:reply:notify:subject' => 'Nueva respuesta en tema: %s',
	'discussion:reply:notify:body' =>
'%s ha respondido al tema %s en el grupo %s:

%s

Ver y comentar:
%s
',

	'groups:activity' => "Actividad del grupo",
	'groups:enableactivity' => 'Habilitar las actividades del grupo',
	'groups:activity:none' => "El grupo no ha tenido actividades a&uacute;n",

	'groups:notfound' => "No se encontr&oacute; el grupo",
	'groups:notfound:details' => "El grupo solicitado no existe o no tienes permiso para verlo",

	'groups:requests:none' => 'No hay solicitudes de membres&iacute;a.',

	'groups:invitations:none' => 'Actualmente no hay invitaciones.',

	'item:object:groupforumtopic' => "Temas de discusi&oacute;n",
	'item:object:discussion_reply' => "Respuestas de la discusión",

	'groupforumtopic:new' => "A&ntilde;adir un tema de discusi&oacute;n",

	'groups:count' => "Grupos creados",
	'groups:open' => "grupo abierto",
	'groups:closed' => "grupo cerrado",
	'groups:member' => "miembros",
	'groups:searchtag' => "Buscar grupos por etiqueta",

	'groups:more' => 'M&aacute;s grupos',
	'groups:none' => 'No hay grupos',

	/**
	 * Access
	 */
	'groups:access:private' => 'Cerrado &mdash; los miembros deben ser invitados',
	'groups:access:public' => 'Abierto &mdash; cualquiera puede unirse',
	'groups:access:group' => 'S&oacute;lo miembros del grupo',
	'groups:closedgroup' => "La membresía de este grupo esta cerrada.",
	'groups:closedgroup:request' => 'Para pedir ser agregado, de click sobre el link "Pedir membresía".',
	'groups:closedgroup:membersonly' => "La membresía de este grupo es cerrada y su contenido solo puede ser accesible para los miembros.",
	'groups:opengroup:membersonly' => "El contenido de este grupo solo es accesible por sus miembros.",
	'groups:opengroup:membersonly:join' => 'Para ser un miembro, de click sobre el link de "Unirse al grupo".',
	'groups:visibility' => '&iquest;Quienes pueden ver este grupo?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Habilitar discusi&oacute;n de los grupos',
	'groups:lastupdated' => '&Uacute;ltimas actualizaciones de %s por %s',
	'groups:lastcomment' => '&Uacute;ltimos de %s por %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Discusi&oacute;n',
	'discussion:add' => 'Agregar tema de discusi&oacute;n',
	'discussion:latest' => '&uacute;ltimas discusiones',
	'discussion:group' => 'Discusiones de grupo',
	'discussion:none' => 'No hay discusiones',
	'discussion:reply:title' => 'Respuesta de %s',

	'discussion:topic:created' => 'El tema de discusi&oacute;n ha sido creado.',
	'discussion:topic:updated' => 'El tema de discusi&oacute;n ha sido actualizado.',
	'discussion:topic:deleted' => 'El tema de discusi&oacute;n ha sido borrado.',

	'discussion:topic:notfound' => 'No se ha encontrado el tema de discusi&oacute;n. solicitado',
	'discussion:error:notsaved' => 'No se puede guardar el tema de discusi&oacute;n',
	'discussion:error:missing' => 'El t&iacute;tulo y el cuerpo del mensaje son obligatorios',
	'discussion:error:permissions' => 'No tienes permiso para hacer eso',
	'discussion:error:notdeleted' => 'No se pudo borrar el tema de discusi&oacute;n',

	'discussion:reply:edit' => 'Editar respuesta',
	'discussion:reply:deleted' => 'La respuesta ha sido borrada.',
	'discussion:reply:error:notfound' => 'La respuesta de la discusión no fue encontrada',
	'discussion:reply:error:notdeleted' => 'No se pudo borrar la respuesta',

	'admin:groups' => 'Grupos',

	'reply:this' => 'Responder a esto',

	'group:replies' => 'Respuestas',
	'groups:forum:created' => 'Creado %s con %d comentarios',
	'groups:forum:created:single' => 'creado %s con %d respuestas',
	'groups:forum' => 'Discusi&oacute;n',
	'groups:addtopic' => 'Agregar un tema',
	'groups:forumlatest' => '&uacute;ltima discusi&oacute;n',
	'groups:latestdiscussion' => '&uacute;ltimas discusiones',
	'groupspost:success' => 'Tu respuesta ha sido publicada',
	'groupspost:failure' => 'Hubo un problema al publicar tu respuesta',
	'groups:alldiscussion' => '&uacute;ltima discusi&oacute;n',
	'groups:edittopic' => 'Editar tema',
	'groups:topicmessage' => 'Mensaje del tema',
	'groups:topicstatus' => 'Estado del tema',
	'groups:reply' => 'Publicar un comentario',
	'groups:topic' => 'Tema',
	'groups:posts' => 'Publicaciones',
	'groups:lastperson' => '&Uacute;ltimo usuario',
	'groups:when' => 'Cuando',
	'grouptopic:notcreated' => 'No hay temas creados.',
	'groups:topicclosed' => 'Cerrado',
	'grouptopic:created' => 'Tu tema ha sido creado.',
	'groups:topicsticky' => 'Sticky',
	'groups:topicisclosed' => 'Esta discusi&oacute;n est&aacute; cerrada.',
	'groups:topiccloseddesc' => 'Este tema est&aacute; cerrado y no acepta nuevas respuestas.',
	'grouptopic:error' => 'El grupo no pudo ser creado. Por favor intenta de nuevo o contacta con el administrador.',
	'groups:forumpost:edited' => "Has editado la entrada exitosamente.",
	'groups:forumpost:error' => "Hubo un problema al editar la entrada.",

	'groups:privategroup' => 'Este es un grupo cerrado. Debes solicitar membresía.',
	'groups:notitle' => 'El grupo debe tener un t&iacute;tulo',
	'groups:cantjoin' => 'No se puedo unir al grupo',
	'groups:cantleave' => 'No se pudo abandonar el grupo',
	'groups:removeuser' => 'Eliminar del grupo',
	'groups:cantremove' => 'No se puede remover este usuario del grupo',
	'groups:removed' => 'El usuario %s ha sido removido del grupo',
	'groups:addedtogroup' => 'El usuario ha sido agregado con &eacute;xito',
	'groups:joinrequestnotmade' => 'No se pudo enviar la solicitud de membres&iacute;a del grupo',
	'groups:joinrequestmade' => 'Solicitar unirse al grupo',
	'groups:joined' => 'Te has unido al grupo',
	'groups:left' => 'Has abandonado el grupo',
	'groups:notowner' => 'No eres el propietario del grupo.',
	'groups:notmember' => 'No eres miembro de este grupo.',
	'groups:alreadymember' => 'Ya eres miembro de este grupo',
	'groups:userinvited' => 'El usuario ha sido invitado.',
	'groups:usernotinvited' => 'El usuario no pudo ser invitado.',
	'groups:useralreadyinvited' => 'El uuario ya ha sido invitado',
	'groups:invite:subject' => "%s te ha invitado al grupo %s",
	'groups:updated' => "&Uacute;ltima respuesta en %s de %s",
	'groups:started' => "Iniciado por %s",
	'groups:joinrequest:remove:check' => '&iquest;Seguro que deseas cancelar la solicitud de membres&iacute;a?',
	'groups:invite:remove:check' => '&iquest;Seguro que deseas anular esta invitaci&oacute;n?',
	'groups:invite:body' => "Hi %s,

%s te ha invitado para que te unas al grupo '%s'. Haz click en el siguiente enlace para unirte:

%s",

	'groups:welcome:subject' => "Bienvenido al grupo %s",
	'groups:welcome:body' => "Hola %s!

Ahora eres miembro de '%s'. Haz click en el siguiente enlace para empezar a postear:

%s",

	'groups:request:subject' => "%s ha solicitado unirse a %s",
	'groups:request:body' => "Hola %s,

%s ha solicitado unirse al grupo '%s'. Click en el siguiente enlace para ver el perfil:

%s

O click a continuaci&oacute;n para ver las solicitudes de membres&iacute;a del grupo:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s ha creado el grupo %s',
	'river:join:group:default' => '%s se ha unido al grupo %s',
	'river:create:object:groupforumtopic' => '%s abri&oacute; el tema %s',
	'river:reply:object:groupforumtopic' => '%s ha respondido en el tema %s',
	'river:reply:view' => 'Ver la respuesta',

	'groups:nowidgets' => 'No se han definido widgets para el grupo.',


	'groups:widgets:members:title' => 'Miembros del grupo',
	'groups:widgets:members:description' => 'Lista de miembros del grupo.',
	'groups:widgets:members:label:displaynum' => 'Lista de miembros de un grupo.',
	'groups:widgets:members:label:pleaseedit' => 'Por favor configura este widget.',

	'groups:widgets:entities:title' => "Objetos en el grupo",
	'groups:widgets:entities:description' => "Lista de objetos guardados en este grupo",
	'groups:widgets:entities:label:displaynum' => 'Lista de objetos de este grupo.',
	'groups:widgets:entities:label:pleaseedit' => 'Por favor configura este widget.',

	'groups:forumtopic:edited' => 'Tema de discusi&oacute;n guaddado con &eacute;xito.',

	'groups:allowhiddengroups' => '&iquest;Desea habilitar los grupos provados?',
	'groups:whocancreate' => '¿Quién puede editar este grupo?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Grupo y contenidos borrados',
	'group:notdeleted' => 'El grupo no pudo ser borrado',

	'group:notfound' => 'No se pudo encontrar el Grupo',
	'grouppost:deleted' => 'Publicaci&oacute;n del grupo borrada con &eacute;xito',
	'grouppost:notdeleted' => 'La publicaci&oacute;n del grupo no se pudoborrar',
	'groupstopic:deleted' => 'Tema eliminado',
	'groupstopic:notdeleted' => 'No se pudo borrar el tema',
	'grouptopic:blank' => 'No hay temas',
	'grouptopic:notfound' => 'No se pude encontrar el tema solicitado',
	'grouppost:nopost' => 'Entrada vacía',
	'groups:deletewarning' => "&iquest;Seguro que deseas borrar este grupo? No se puede deshacer",

	'groups:invitekilled' => 'El invitado ha sido eliminado.',
	'groups:joinrequestkilled' => 'La solicitud ha sido borrada.',
	'groups:error:addedtogroup' => "No ha sido posible añadir a %s al grupo.",
	'groups:add:alreadymember' => "%s ya forma parte del grupo.",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Discusi&oacute;n de los grupos',
	'groups:ecml:groupprofile' => 'Pefiles de los grupos',
);
